@@ -4,9 +4,9 @@
 # Created On       : Wed Jan 22 09:53:33 1997
 # Created On Node  : tiamat.datasync.com
 # Last Modified By : Manoj Srivastava
-# Last Modified On : Tue Mar 10 11:12:18 1998
-# Last Machine Used: tiamat.datasync.com
-# Update Count     : 332
+# Last Modified On : Sat May 15 05:34:10 1999
+# Last Machine Used: glaurung.green-gryphon.com
+# Update Count     : 348
 # Status           : Unknown, Use with caution!
 # HISTORY          : 
 # Description      : 
@@ -68,6 +68,7 @@ sub new{
   my %params = @_;
   my $class = ref($this) || $this;
   my $self = {};
+  $Debug{'Routines'}=0;
   
   if ($Debug{'Routines'}) {
     print STDERR "Routine: Debian::Package::Dependency->new\n";
@@ -216,7 +217,7 @@ checking is done using the routine do_depend. This is the routine that
 adds ordering information to the array if the current packageis not a
 virtual package. In case there is a version mismatch within the new
 list, this is a cause for concern, and if the parameter Consistent is
-defined, it prints a warning on stderr.
+defined, it prints a warning on stderr. 
 
 =cut
 
@@ -237,6 +238,11 @@ sub depend {
   
   $Results = $self->do_depend($params->{'New'}, $params->{'Package'});
   
+  print STDERR "\tDEBUG: (dependency.pm):240 ",
+  "dependency  $self->{'Name'} type $self->{'Type'}", 
+    "\n\t\t Package: $params->{'Package'}->{'Package'}", 
+    " ($params->{'Package'}->{'Version'})\n "
+    if $self->{' _Debug'};
   print STDERR "\tDEBUG: (dependency.pm):241 $self->{'Name'}" 
     if $self->{' _Debug'};
   print STDERR "($self->{'Rel'} $self->{'Ver'})" 
@@ -255,11 +261,15 @@ sub depend {
 		  "$self->{'Name'}" ;
 	$msg .= "($self->{'Rel'} $self->{'Ver'})" if $self->{'Ver'};
 	$msg .= "\n";
+	print STDERR "\tDEBUG: (dependency.pm):264 $self->{'Name'}",
+	"\n\t/Failed, add 'Type'=$self->{'Type'}",
+	"\n\t'Category' = Warn,'Report' = $msg\n"
+	  if $self->{' _Debug'};
+
         $params->{'Package'}->{' _Results'}->add('Type' => $self->{'Type'},
 						 'Category' => "Warn",
 						 'Report' => $msg);
       }
-      last;
     };
     
     /Conflict/ && do {
@@ -273,14 +283,18 @@ sub depend {
 		  "$self->{'Name'}" ;
 	$msg .= "($self->{'Rel'} $self->{'Ver'})" if $self->{'Ver'};
 	$msg .= "\n";
+	print STDERR "\tDEBUG: (dependency.pm):287 $self->{'Name'}",
+	"\n\t/Conflict, add 'Type'=$self->{'Type'}",
+	"\n\t'Category' = Warn,'Report' = $msg\n"
+	  if $self->{' _Debug'};
         $params->{'Package'}->{' _Results'}->add('Type' => $self->{'Type'},
 						 'Category' => "Warn",
 						 'Report' => $msg);
-	$params->{'New'}->{' _Targets'}->add
-	  ('Type' => $self->{'Type'},
-	   'Target' => $self->{'Name'},
-	   'Dependant' => $params->{'Package'}->{'Package'});
       }
+      $params->{'New'}->{' _Targets'}->add
+	('Type' => $self->{'Type'},
+	 'Target' => $self->{'Name'},
+	 'Dependant' => $params->{'Package'}->{'Package'});
       last;
     };
     
@@ -316,7 +330,7 @@ sub depend {
       }
     };
 
-    /Unknown/ && do {
+    /Unknown|Failed/ && do {
       # Try the installed list
       if ($params->{'Installed'}) {
         $Results = 
@@ -388,6 +402,10 @@ sub depend {
 	if ($params->{'Warn'}) {
 	  $category = "Warn";
 	}
+	print STDERR "\tDEBUG: (dependency.pm):398 $self->{'Name'}",
+	"\n\tNot conflict, not unknow, remove 'Type'=$self->{'Type'}",
+	"\n\t'Category' = $category,'Report' = $report\n"
+	  if $self->{' _Debug'};
 	$params->{'Package'}->{' _Results'}->remove
 	  ('Type' => $self->{'Type'},
 	   'Category' => "$category",
@@ -398,6 +416,10 @@ sub depend {
 	if ($params->{'Warn'}) {
 	  $category = "Warn";
 	}
+	print STDERR "\tDEBUG: (dependency.pm):411 $self->{'Name'}",
+	"\n\tNot conflict, unknow, add 'Type'=$self->{'Type'}",
+	"\n\t'Category' = $category,'Report' = $report\n"
+	  if $self->{' _Debug'};
 	$params->{'Package'}->{' _Results'}->add
 	  ('Type' => $self->{'Type'},
 	   'Category' => "$category",
@@ -406,6 +428,10 @@ sub depend {
     }
 
     /Success|Provided/ && do {
+	print STDERR "\tDEBUG: (dependency.pm):423 $self->{'Name'}",
+	"\n\tSuccess|Provided, add 'Type'=$self->{'Type'}",
+	"\n\t'Category' = $category,'Report' = $report\n"
+	  if $self->{' _Debug'};
       $params->{'Package'}->{' _Results'}->add('Type' => $self->{'Type'},
 					       'Category' => "Found",
 					       'Report' => $report);
@@ -417,6 +443,10 @@ sub depend {
       if ($params->{'Warn'}) {
 	$category = "Warn";
       }
+	print STDERR "\tDEBUG: (dependency.pm):438 $self->{'Name'}",
+	"\n\tConflict, add 'Type'=$self->{'Type'}",
+	"\n\t'Category' = $category,'Report' = $report\n"
+	  if $self->{' _Debug'};
       $params->{'Package'}->{' _Results'}->add('Type' => $self->{'Type'},
 					       'Category' => $category,
 					       'Report' => $report);
@@ -428,6 +458,10 @@ sub depend {
         if ($params->{'Warn'}) {
            $category = "Warn";
         }
+	print STDERR "\tDEBUG: (dependency.pm):453 $self->{'Name'}",
+	"\n\t/Failed, add 'Type'=$self->{'Type'}",
+	"\n\t'Category' = $category,'Report' = $report\n"
+	  if $self->{' _Debug'};
         $params->{'Package'}->{' _Results'}->add('Type' => $self->{'Type'},
        					         'Category' => $category,
 					         'Report' => $report);
@@ -528,13 +562,24 @@ sub do_depend {
 	  $ret = 'Conflict'; 
 	}
 	else {
-	  #Well, this is clearly not a problem, right? Neither is this
-	  #unknown, but, if we return provided, which means we both
-	  #conflict with and provide this, it means that the caller
-	  #routine, depends, shall not check the installed packages,
-	  #and we may well miss a conflict. There fore, we return
-	  #Unknown, rather than provided. I hate special cases.
-	  $ret = 'Unknown'; 
+	  # Test to see if anyone else provided this too
+	  if ($pkg->{'Package'} eq $pkg_list->{' _Provided'}->{$Name}) {
+	    #Well, this is clearly not a problem, right? Neither is
+	    #this unknown, but, if we return provided, which means we
+	    #both conflict with and provide this, it means that the
+	    #caller routine, depends, shall not check the installed
+	    #packages, and we may well miss a conflict. There fore, we
+	    #return Unknown, rather than provided. I hate special
+	    #cases.
+	    print STDERR "\tDEBUG: (dependency.pm):543 $self->{'Name'}",
+	    "We provide this, as well as conflict with this\n"
+	      if $self->{' _Debug'};
+	    $ret = 'Unknown'; 
+	  }
+	  else {
+	    # Someone else provides this too!!
+	    $ret = 'Conflict'; 
+	  }
 	}
       }
       else {
@@ -543,6 +588,14 @@ sub do_depend {
     }
   }
   
+  # A package does not conflict with itself
+
+  if($ret =~ /Conflict/) {
+    if ($Name eq $pkg->{'Package'}) {
+      $ret = 'Noconflict'; 
+    }
+  }
+  
   # Well, if it is a conflict, maybe we replace a Package as well
   
   if($ret =~ /Conflict/  && $Replaces) {
@@ -601,6 +654,7 @@ sub order {
   - there is a conflict with the installed list
 
 =cut 
+
 =pod
 
  If there is a dependency from the conflicted-with package to
