@@ -4,9 +4,9 @@
 # Created On       : Wed Jan 29 17:27:18 1997
 # Created On Node  : tiamat.datasync.com
 # Last Modified By : Manoj Srivastava
-# Last Modified On : Thu Apr  2 15:29:27 1998
-# Last Machine Used: tiamat.datasync.com
-# Update Count     : 249
+# Last Modified On : Sun May 16 09:06:36 1999
+# Last Machine Used: glaurung.green-gryphon.com
+# Update Count     : 263
 # Status           : Unknown, Use with caution!
 # HISTORY          : 
 # Description      : 
@@ -29,7 +29,7 @@ use Debian::Package::Package;
 package Debian::Package::List;
 use Carp;
 use FileHandle;
-use IPC::Open2;
+use IPC::Open3;
 
 
 =head1 SYNOPSIS
@@ -254,7 +254,7 @@ This is the generic function for comparing version numbers. It takes
 three arguments, one version number, a relation, and another version
 number. Relation can be what dpkg would accept as relations (i.e., <,
 <<, <=, =, >=, >>, and >). The result is a boolean value.
-	
+
 =cut
 
 sub compare_versions {
@@ -803,6 +803,9 @@ sub order {
     $Arguments{'New'}       = $self;
     $Arguments{'Installed'} = $params{'Installed'} if 
       $params{'Field'} eq 'Conflicts';
+    print STDERR "\tDEBUG: List.pm 807: $self->{$name}->{'Package'}  $params{'Field'}\n"
+      if $self->{' _Debug'};
+    
     $self->{$name}->{" _$params{'Field'}"}->order($arg);
   }
 }
@@ -825,6 +828,9 @@ sub order_string {
     my $new_string = '';
     
     $new_string = $self->{$name}->order_string();
+    print STDERR "\tDEBUG: List.pm 831 == $new_string\n"
+      if $self->{' _Debug'};
+    
     $string .= $new_string if $new_string;
   }
   return $string;
@@ -845,12 +851,22 @@ sub get_ordering {
   my $string = '';
   my $pid = 0;
   my $output = '';
+  my $errout = '';
   
   $string = $self->order_string();
-  $pid = open2( \*Reader, \*Writer, "tsort" );
+  $pid = open3( \*Writer, \*Reader, \*ErrorPipe, "tsort" );
   Writer->autoflush(); # default here, actually
   print Writer "$string";
   Writer->close() or die "Could not close writer pipe:$!";
+  
+  while (<ErrorPipe>) { $errout .= $_; }
+  ErrorPipe->close() or die "Could not close stderr pipe:$!";
+  if ($errout) {
+    print STDERR "External tsort invocation returned an error:\n";
+    print STDERR $errout;
+    print STDERR "";
+  } ;
+
   while (<Reader>) { $output .= $_; }
   Reader->close() or die "Could not close reader pipe:$!";
   return $output;
