@@ -4,9 +4,9 @@
 # Created On       : Wed Jan 29 17:32:40 1997
 # Created On Node  : tiamat.datasync.com
 # Last Modified By : Manoj Srivastava
-# Last Modified On : Mon Mar 16 13:02:29 1998
-# Last Machine Used: tiamat.datasync.com
-# Update Count     : 168
+# Last Modified On : Sat May 15 05:26:58 1999
+# Last Machine Used: glaurung.green-gryphon.com
+# Update Count     : 191
 # Status           : Unknown, Use with caution!
 # HISTORY          : 
 # Description      : 
@@ -175,6 +175,11 @@ sub order_string {
       "Not including $self->{'Package'} $errors Errors \n";
     return '';
   }
+  else {
+    print STDERR 
+      "\tDEBUG:Package.pm:180: including $self->{'Package'} $errors Errors \n"
+	if $self->{' _Debug'};
+  }
   
   $string = "START $self->{'Package'}\n";
   for (@{$self->{' _Order'}}) {
@@ -232,6 +237,7 @@ sub check_relations {
   $ret = $self->{" _$params{'Field'}"}->depend($arg);
   print STDERR "\tDEBUG: (package.pm):188 $self->{'Package'} checked as $ret\n" 
     if $self->{' _Debug'};
+  $ret;
 }
 
 =head2 reset_result 
@@ -396,7 +402,7 @@ sub new {
   
   
   bless $self => $class;
-  $self->{'Show Stoppers'} = "Pre-Depends Depends Conflict";
+  $self->{'Show Stoppers'} = "Pre-Depends Depends Conflicts";
   $self->{'Special'} = "Critical All";    
   $self->{'Package'} = $package;
   $self->{' _Debug'} = 0;
@@ -446,7 +452,7 @@ sub add {
   croak("Required parameter 'Report' absent") 
     unless $params{'Report'};
 
-  printf STDERR "\tDEBUG: add Type=$params{'Type'} Category=$params{'Category'}"
+  printf STDERR "\tDEBUG: 450 $self->{'Package'} add Type=$params{'Type'} Category=$params{'Category'}"
       if $self->{' _Debug'};
   printf STDERR " Report=$params{'Report'}\n" 
     if $self->{' _Debug'};
@@ -517,10 +523,10 @@ sub remove {
   if ($#{$array} > -1) {
     foreach (@{$array}) {
       if ($self->{' _Debug'}) {
-	print STDERR "DEBUG: Considering $_ ($pattern)\n";
-	print STDERR "DEBUG:removing $_ ($pattern) from results\n" 
+	print STDERR "DEBUG: 521 $self->{'Package'}Considering $_ ($pattern)\n";
+	print STDERR "DEBUG: 522 $self->{'Package'}removing $_ ($pattern) from results\n" 
 	  if m/^$pattern$/;
-	print STDERR "DEBUG: Not removing $_ ($pattern) from results\n"
+	print STDERR "DEBUG: 523 $self->{'Package'}Not removing $_ ($pattern) from results\n"
 	  unless m/^$pattern$/;
       }
       push (@tmparray, $_) unless m/^$pattern$/;
@@ -683,7 +689,6 @@ sub do_string {
     unless $params{'Category'}; 
 
   $array = $self->{'Results'}->{$params{'Category'}}->{$params{'Type'}};
-					      
   if ($#$array > -1) {
     $string .= "   Package: $self->{'Package'}\n";
     foreach (@$array) {
@@ -721,24 +726,41 @@ sub check {
 
   my $pattern = $params{'Type'};
   $pattern =~ s/(\W)/\\$1/g;
-  if ($self->{'Special'} =~ m/$pattern/i) {
+  print STDERR "\nPackage.pm:727: $self->{'Package'} Type ",
+  "$params{'Type'} Category $params{'Category'} pattern $pattern\n" 
+    if $self->{' _Debug'};
+  if ("All Critical" =~ m/$pattern/i) {
     if ($params{'Type'} =~ m/All/i) {
       for (keys %{$self->{'Results'}->{$params{'Category'}}}) {
 	$count +=  1 +
 	  $#{$self->{'Results'}->{$params{'Category'}}->{$_}};
+	print STDERR "Package.pm:737: Type $_  ",
+	"error: $count\n" 
+	  if $self->{' _Debug'};
       }
     }
     if ($params{'Type'} =~ m/Critical/i) {
       for (split(' ', $self->{'Show Stoppers'})) {
 	$count += 1 +
 	  $#{$self->{'Results'}->{$params{'Category'}}->{$_}};
+	print STDERR "Package.pm:746: Type $_ ",
+	"error: $count\n" 
+	  if $self->{' _Debug'};
       }
     }
   }
   else {
     $count += 1 +
       $#{$self->{'Results'}->{$params{'Category'}}->{$params{'Type'}}};
+    print STDERR "Package.pm:755: Category $params{'Category'} ",
+    "error: $count\n" 
+    if $self->{' _Debug'};
   }
+  print STDERR "Package.pm:759: $self->{'Package'} Type ",
+  "$params{'Type'} Category $params{'Category'} ",
+  "Final error: $count\n" 
+    if $self->{' _Debug'};
+  
   return $count;
 }
 
